# xattrs

[![PyPI - Version](https://img.shields.io/pypi/v/xattrs.svg)](https://pypi.org/project/xattrs)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/xattrs.svg)](https://pypi.org/project/xattrs)

---

🚧 **WIP**

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install xattrs
```

## License

`xattrs` is distributed under the terms of the
[BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
